'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var os = require('os');
var path = require('path');
var makeFetchHappen = require('make-fetch-happen');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var makeFetchHappen__default = /*#__PURE__*/_interopDefault(makeFetchHappen);

// src/scheme.ts
function regex_escape(str) {
  return str.replace(/[.*+?^${}()|[\]\\]/g, "\\$&");
}
function make_regex(schemes) {
  return new RegExp("^(" + schemes.map(regex_escape).join("|") + "):");
}
function noop() {
}
var cachePath = /* @__PURE__ */ path.join(/* @__PURE__ */ os.tmpdir(), "@hyrious/esbuild-plugin-http-cache");
async function fetch(url, agent, cache, onfetch = noop) {
  let contents = cache.get(url);
  if (contents)
    return contents;
  const options = { cachePath };
  if (agent)
    options.agent = agent;
  onfetch(url);
  contents = await makeFetchHappen__default.default(url, options).then((r) => r.text());
  cache.set(url, contents);
  return contents;
}

// src/plugin.ts
function http({
  filter,
  agent = null,
  schemes = {},
  cache = /* @__PURE__ */ new Map(),
  onfetch
} = {}) {
  return {
    name: "http",
    setup({ onResolve, onLoad }) {
      let scheme_filter;
      let scheme_keys = Object.keys(schemes);
      if (scheme_keys.length > 0) {
        scheme_filter = make_regex(scheme_keys);
      }
      let filter_func = filter === void 0 ? function(url) {
        return true;
      } : typeof filter === "function" ? filter : function(url) {
        return filter.test(url);
      };
      if (scheme_filter) {
        onResolve({ filter: scheme_filter }, ({ path }) => {
          let key = scheme_keys.find((prefix2) => path.startsWith(prefix2 + ":"));
          let prefix = schemes[key];
          let search = "";
          let idx = prefix.indexOf("?");
          if (idx !== -1) {
            search = prefix.slice(idx);
            prefix = prefix.slice(0, idx);
          }
          let url = prefix + path.slice(key.length + 1) + search;
          if (filter_func(url)) {
            return { path: url, namespace: "http-url" };
          }
        });
      }
      onResolve({ filter: /^https?:\/\// }, (args) => {
        if (filter_func(args.path)) {
          return { path: args.path, namespace: "http-url" };
        }
      });
      onResolve({ filter: /.*/, namespace: "http-url" }, (args) => ({
        path: new URL(args.path, args.importer).toString(),
        namespace: "http-url"
      }));
      onLoad({ filter: /.*/, namespace: "http-url" }, async (args) => {
        let contents = await fetch(args.path, agent, cache, onfetch);
        return { contents, loader: "default" };
      });
    }
  };
}
var default_schemes = {
  unpkg: "https://unpkg.com/?module",
  jsdelivr: "https://esm.run/",
  esm: "https://esm.sh/?bundle"
};

exports.default = http;
exports.default_schemes = default_schemes;
exports.http = http;
//# sourceMappingURL=index.js.map